int bk_set_timeout(int x);
int bk_set_workarea(char *work);
int bk_set_disk_cache(int x);
int mx_lookup_que(char *name, void (*fn)(int n, char *s, int isfb),int n);
int mx_bkgnd(int thischan, int msec);
int bk_add_nameserver(char *s);
int bk_init(int (*vdmsg)(const char * arg_list, ...),int (*vimsg)(const char * arg_list, ...),int (*vemsg)(const char * arg_list, ...));
int mx_set_timeout(int x, int secs);
int mx_set_orbs(int x, int isorbs);
int bk_clear_nameserver(void);
int dns_reset_main(void);
int dns_corrupt(void);
int dns_set_quiet(int x);
int mx_set_type(int x, char *xtype);
int dns_disk_lookup(char *name, char *result);
int dns_exit(void);
void mx_free(void);
void mxc_exit();
int mx_nfree(void);

int dns_disk_add(char *name, char *result, int dodisk);
int dns_disk_lookup(char *name, char *result);
int dns_set_ipv6(int x);
int get_short(unsigned char **s);
int get_long(unsigned char **s);
void bk_putshort(u_int src, u_char *dst);
char *dns_type_name(int x);